pub fn decode_identity_update(
envelope: ServerEnvelope,
) -> Result<IdentityUpdateLog, EnvelopeError>Expand description
Decode an identity update and check its inbox topic.
pub fn decode_identity_update(
envelope: ServerEnvelope,
) -> Result<IdentityUpdateLog, EnvelopeError>Decode an identity update and check its inbox topic.