pub fn decode_key_package(
envelope: ServerEnvelope,
) -> Result<KeyPackage, EnvelopeError>Expand description
Decode a key package returned by a full newest query.
pub fn decode_key_package(
envelope: ServerEnvelope,
) -> Result<KeyPackage, EnvelopeError>Decode a key package returned by a full newest query.