chunk_mutate_adds

Function chunk_mutate_adds 

pub fn chunk_mutate_adds<C>(adds: Vec<(Topic, C)>) -> Vec<Vec<(Topic, C)>>
Split an add set into updates within the backend count and byte limits. The caller must also enforce the total topic limit for its connection.